@@ -2,7 +2,6 @@
 
 use super::image_source::ImageSource;
 use std::{
-    convert::TryFrom,
     error::Error,
     fmt::{Display, Formatter, Result as FmtResult},
     mem,
@@ -476,7 +475,7 @@ impl EmbedBuilder {
     ///
     /// Create an embed author:
     ///
-    /// ```rust
+    /// ```
     /// use twilight_embed_builder::{EmbedAuthorBuilder, EmbedBuilder};
     ///
     /// # fn main() -> Result<(), Box<dyn std::error::Error>> {
@@ -507,7 +506,7 @@ impl EmbedBuilder {
     ///
     /// Set the color of an embed to `0xfd69b3`:
     ///
-    /// ```rust
+    /// ```
     /// use twilight_embed_builder::EmbedBuilder;
     ///
     /// # fn main() -> Result<(), Box<dyn std::error::Error>> {
@@ -532,7 +531,7 @@ impl EmbedBuilder {
     ///
     /// # Examples
     ///
-    /// ```rust
+    /// ```
     /// use twilight_embed_builder::EmbedBuilder;
     ///
     /// # fn main() -> Result<(), Box<dyn std::error::Error>> {
@@ -555,7 +554,7 @@ impl EmbedBuilder {
     ///
     /// # Examples
     ///
-    /// ```rust
+    /// ```
     /// use twilight_embed_builder::{EmbedBuilder, EmbedFieldBuilder};
     ///
     /// # fn main() -> Result<(), Box<dyn std::error::Error>> {
@@ -579,7 +578,7 @@ impl EmbedBuilder {
     ///
     /// # Examples
     ///
-    /// ```rust
+    /// ```
     /// use twilight_embed_builder::{EmbedBuilder, EmbedFooterBuilder};
     ///
     /// # fn main() -> Result<(), Box<dyn std::error::Error>> {
@@ -605,7 +604,7 @@ impl EmbedBuilder {
     ///
     /// Set the image source to a URL:
     ///
-    /// ```rust
+    /// ```
     /// use twilight_embed_builder::{EmbedBuilder, EmbedFooterBuilder, ImageSource};
     ///
     /// # fn main() -> Result<(), Box<dyn std::error::Error>> {
@@ -634,7 +633,7 @@ impl EmbedBuilder {
     /// Set the thumbnail to an image attachment with the filename
     /// `"twilight.png"`:
     ///
-    /// ```rust
+    /// ```
     /// use twilight_embed_builder::{EmbedBuilder, ImageSource};
     ///
     /// # fn main() -> Result<(), Box<dyn std::error::Error>> {
@@ -671,7 +670,7 @@ impl EmbedBuilder {
     ///
     /// Set the title to "twilight":
     ///
-    /// ```rust
+    /// ```
     /// use twilight_embed_builder::EmbedBuilder;
     ///
     /// # fn main() -> Result<(), Box<dyn std::error::Error>> {
@@ -699,7 +698,7 @@ impl EmbedBuilder {
     ///
     /// Set the URL to [twilight's repository]:
     ///
-    /// ```rust
+    /// ```
     /// use twilight_embed_builder::{EmbedBuilder, EmbedFooterBuilder};
     ///
     /// # fn main() -> Result<(), Box<dyn std::error::Error>> {
@@ -747,7 +746,7 @@ mod tests {
     use super::{EmbedBuilder, EmbedError, EmbedErrorType};
     use crate::{field::EmbedFieldBuilder, footer::EmbedFooterBuilder, image_source::ImageSource};
     use static_assertions::{assert_fields, assert_impl_all, const_assert};
-    use std::{convert::TryFrom, error::Error, fmt::Debug};
+    use std::{error::Error, fmt::Debug};
     use twilight_model::{
         channel::embed::{Embed, EmbedField, EmbedFooter},
         datetime::Timestamp,
